fill.NA: Replacement of missing values

Description Usage Arguments Value Note Author(s) Examples

View source: R/fill.NA.R

Description

Methods for replacement of missing values. Missing values should be indicated by NA in the expression matrix.

Usage

1
fill.NA(eset,mode="mean",k=10)

Arguments

eset

object of the class ExpressionSet.

mode

method for replacement of missing values:

  • mean- missing values will be replaced by the mean expression value of the gene,

  • median- missing values will be replaced by the median expression value of the gene,

  • knn- missing values will be replaced by the averging over the corresponding expression values of the k-nearest neighbours,

  • knnw-same replacement method as knn, but the expression values averaged are weighted by the distance to the corresponding neighbour

k

Number of neighbours, if one of the knn method for replacement is chosen (knn,knnw).

Value

The function produces an object of the ExpressionSet class with missing values replaced.

Note

The replacement methods knn and knnw can computationally intensive for large gene expression data sets. It may be a good idea to run these methods as a ‘lunchtime’ or ‘overnight’ job.

Author(s)

Matthias E. Futschik (http://itb.biologie.hu-berlin.de/~futschik) and Lokesh Kumar

Examples

1
2
3
4
5
if (interactive()){
data(yeast) # data set includes 17 measurements
yeastF <- filter.NA(yeast) 
yeastF <- fill.NA(yeastF)
}

Example output

Loading required package: Biobase
Loading required package: BiocGenerics
Loading required package: parallel

Attaching package: ‘BiocGenerics’

The following objects are masked from ‘package:parallel’:

    clusterApply, clusterApplyLB, clusterCall, clusterEvalQ,
    clusterExport, clusterMap, parApply, parCapply, parLapply,
    parLapplyLB, parRapply, parSapply, parSapplyLB

The following objects are masked from ‘package:stats’:

    IQR, mad, sd, var, xtabs

The following objects are masked from ‘package:base’:

    anyDuplicated, append, as.data.frame, basename, cbind, colnames,
    dirname, do.call, duplicated, eval, evalq, Filter, Find, get, grep,
    grepl, intersect, is.unsorted, lapply, Map, mapply, match, mget,
    order, paste, pmax, pmax.int, pmin, pmin.int, Position, rank,
    rbind, Reduce, rownames, sapply, setdiff, sort, table, tapply,
    union, unique, unsplit, which.max, which.min

Welcome to Bioconductor

    Vignettes contain introductory material; view with
    'browseVignettes()'. To cite Bioconductor, see
    'citation("Biobase")', and for packages 'citation("pkgname")'.

Loading required package: e1071

Attaching package: ‘DynDoc’

The following object is masked from ‘package:BiocGenerics’:

    path

Warning message:
no DISPLAY variable so Tk is not available 

Mfuzz documentation built on Nov. 8, 2020, 5:22 p.m.